@@ -135,7 +135,7 @@
 			       "application/octet-stream"))
 		     mm-uu-decode-function nil 
 		     (if (and file-name (not (equal file-name "")))
-			 (list "attachment" (cons 'filename file-name)))))
+			 (list "inline" (cons 'filename file-name)))))
 	      ((eq type 'binhex)
 	       (mm-make-handle (mm-uu-copy-to-buffer start-char end-char) 
 		     (list (or (and file-name
@@ -145,7 +145,7 @@
 			       "application/octet-stream"))
 		     mm-uu-binhex-decode-function nil 
 		     (if (and file-name (not (equal file-name "")))
-			 (list "attachment" (cons 'filename file-name)))))
+			 (list "inline" (cons 'filename file-name)))))
 	      ((eq type 'shar)
 	       (mm-make-handle (mm-uu-copy-to-buffer start-char end-char) 
 		     '("application/x-shar")))) 
