@@ -166,6 +166,7 @@
 	    (nnmbox-article-group-number)))))))
 
 (deffoo nnmbox-request-group (group &optional server dont-check)
+  (nnmbox-possibly-change-newsgroup nil server)
   (let ((active (cadr (assoc group nnmbox-group-alist))))
     (cond
      ((or (null active)
@@ -425,8 +426,9 @@
     (save-excursion
       (set-buffer (setq nnmbox-mbox-buffer
 			(nnheader-find-file-noselect
-			 nnmbox-mbox-file nil 'raw)))
-      (buffer-disable-undo (current-buffer))))
+			 nnmbox-mbox-file nil t)))
+      (mm-enable-multibyte)
+      (buffer-disable-undo)))
   (when (not nnmbox-group-alist)
     (nnmail-activate 'nnmbox))
   (if newsgroup
@@ -512,8 +514,9 @@
 	    start end number)
 	(set-buffer (setq nnmbox-mbox-buffer
 			  (nnheader-find-file-noselect
-			   nnmbox-mbox-file nil 'raw)))
-	(buffer-disable-undo (current-buffer))
+			   nnmbox-mbox-file nil t)))
+	(mm-enable-multibyte)
+	(buffer-disable-undo)
 
 	;; Go through the group alist and compare against
 	;; the mbox file.
